#!/bin/sh

# Note:
#	Every printf (or any write to stdout) will go to modem because this
#	is piped in to stdin of cu -l ttyS1
#
#	Also note that the output from modem (including the local echo) all
#	will go to stdin of outFromCu.sh, which reads its standin and 
#	writes eveything into the file $CHECK_FILE
#

CHECK_FILE=/tmp/cu.chkfile.${PPID} # DON't Change this name -- it is also used in outFromCu.sh
> $CHECK_FILE

# we return 100 for active
#           101 for standby
#           102 for unknown state
getHaStat() {
	hastat=102
	retCode=`/fabos/cliexec/hashow | grep Local |  grep -c Active`
	[ $retCode -eq 1 ] && hastat=100
	retCode=`/fabos/cliexec/hashow | grep Local |  grep -c Standby`
	[ $retCode -eq 1 ] && hastat=101
}

# this function is used to send the string $1 to modem (usint printf)
# and then make sure this sequence got there

sendAndConfirm() {
	# $1 is the string that we wanted to send out

	inStr="$1"
	Pbegin=0
# DEBUG printf "Sending '%s' ----->\n" "$inStr" > /dev/console

# if we send too long strings, we get overrun! so, to avoid we have to
# break the inStr into pieces of Psz and then send them
	while :
	do
		sleep 1
		Pend=`expr $Pbegin + $Psz`
		thisStr=`printf "$inStr" | sed -e "s/\(^.\{0,${Pbegin}\}\)\(.\{0,${Psz}\}\)\(.*\)/\2/"`
		[ -z "$thisStr" ] && break
		Pbegin=$Pend
		printf "${thisStr}"
	done

	printf "\r" # required so the modem takes the previous inputs
	sleep 1
	chkIdx=`expr ${chkIdx} + 1`
	chkStr=`printf "#%d#" $chkIdx`
	printf "at%s\r" "$chkStr"
	retryCount=1
	while [ $retryCount -lt 60 ]
	do
		sleep 1
		rv=`grep -c $chkStr ${CHECK_FILE}`
		if [ "$rv" -ge 1 ]
		then
			return
		fi
# DEBUG printf "retry.. 'at %s\n'  ------->>>\n" $chkStr > /dev/console
		retryCount=`expr $retryCount + 1`
	done
# we cannot confirm, either the modem has gone bad or ....
	printf "
setmodem.sh: WARNING: Can't detect any MODEM on ttyS1.
" > /dev/console
	printf "atV1\r"
	printf "atQ0\r"
	printf "\r~.\n"
	sleep 120
	[ -f /var/lock/LCK..ttyS1 ] && CU_PID=`cat /var/lock/LCK..ttyS1`
	[ -f /var/lock/LCK..ttyS1 ] && kill -9 $CU_PID 2> /dev/null
	rm -f /var/lock/LCK..ttyS1 2> /dev/null
	exit 1
}

# main function script starts here
chkIdx=77
Psz=1 # size that we will print at a time to avoid tty overruns

# let us see if setmodem is chkconfig on
chkconfig setmodem
if [ $? -eq 1 ] ;
then
	printf "setmodem: disabling modem access\n" > /dev/console
	# get modem back to command mode
	printf "+++"
	# wait at least the mandatory 1 second after the "+++"
	sleep 2
	# tell modem to not answer the phone
	printf "ATS0=0\r"
	exit 1
fi

getHaStat

case $hastat in
100)
# if we are active we answer the phone at the first ring
	answerRings=1;
# if we are active, let us wait a bit untill dust settles down
# this is to avoid, during failvoer, both modems from answering
# We will sleep here a 100 seconds allowing the ex-active to become
# standby to set modem ringing to 7 rings
	sleep 100

	;;
101)
# if we are standby we answer the phone at the (seventh) ring
	answerRings=7;
	;;
*)
# We don't know who we are :-(
# Hmm, lets answer at, Uhh.. Umm.., howabout (fourth) ring? Huh...!
	answerRings=4;
	;;
esac

idx=0

# we cannot send and confirm if there is no echo
# so the turnning echo on has to be done with printf
printf "ATE1\r"	# turn echo on
sleep 1
printf "ATE1\r"	# If the previous was rejected because of some residue...
sleep 1

sendAndConfirm "ATV0" # turn off the verbous mode (to avoid tty overruns)
sendAndConfirm "ATQ1" # turn on the quite mode (to avoid tty overruns)
sendAndConfirm "ATS1" # Follows EIA spec. (Active following carrier tone
			#  until carrier is lost

sendAndConfirm "at #MGCSTRNG#" # this is our magic string
rv=`grep -c "MGCSTRNG" ${CHECK_FILE}`
if [ "X$rv" != "X1" ] ;
then
	printf "
setmodem.sh: WARNING: Can't detect any modem on ttyS1.
" > /dev/console
	sendAndConfirm "atV1"
	sendAndConfirm "atQ0"
	printf "\r~.\n"
	printf "\r~.\n"
	sleep 120
	[ -f /var/lock/LCK..ttyS1 ] && CU_PID=`cat /var/lock/LCK..ttyS1`
	[ -f /var/lock/LCK..ttyS1 ] && kill -9 $CU_PID 2> /dev/null
	rm -f /var/lock/LCK..ttyS1 2> /dev/null
	exit 1
fi

sendAndConfirm "AT&Y"	# Power-on profile load
sendAndConfirm "AT&W"	# Store values on on volotile

tmpStr=`printf "atS0=%d" $answerRings`
sendAndConfirm "$tmpStr"
sendAndConfirm "at #SPEEDFOLLOWS#"
sendAndConfirm "atS0?"
# some modems leaves a blank line for the above question
for jval in 3 4 5
do
	setValue=`tr "\r" -t "\n" < ${CHECK_FILE} |  sed -e '1,/SPEEDFOLLOWS/d' | head -$jval | tail -1 | cut -c0-3 `
	chkValue=`echo $setValue | sed -e 's/[0-9][0-9]*/X/'`
	[ "$chkValue" = "X" ] && break
done
cp ${CHECK_FILE} ${CHECK_FILE}.old
if [ "X" = "X$setValue" -o $setValue -ne $answerRings ] ; 
then
	printf "
setmodem.sh: WARNING: Can't initialize the modem on ttyS1.
" > /dev/console
else
	printf "
setmodem.sh: INFO: Modem has been set to answer at ring count: %d
" $answerRings > /dev/console
fi
sendAndConfirm "atV1"
sendAndConfirm "atQ0"
printf "~.\r"
